==> haskell-rio-prettyprint-0.1.6.0-20-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.6.0
visibility:           public
id:                   rio-prettyprint-0.1.6.0-JKUDN2v8H83Oh6awut1Lb
key:                  rio-prettyprint-0.1.6.0-JKUDN2v8H83Oh6awut1Lb
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  1dae780622f8a4c0565fbfeb1bfe788a
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.6.0-JKUDN2v8H83Oh6awut1Lb
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-6EBV889cSS7AqjoZtYoje8
    annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
    ansi-terminal-0.11.4-Bavr5INHzaUHF3VuHy0Lqz array-0.5.4.0
    base-4.16.4.0 colour-2.3.6-Lb0j5FHWynL92WxSgZCtF8 mtl-2.2.2
    path-0.9.5-IRiljrQkWe5KvlpCrQH9Mz
    rio-0.1.22.0-Bs52vTxxPqs4Bge6aUVYDC text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rio-prettyprint-0.1.6.0-29-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rio-prettyprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rio-prettyprint
version:              0.1.6.0
visibility:           public
id:                   rio-prettyprint-0.1.6.0-HC5utweDa8VL0DUiYO0v68
key:                  rio-prettyprint-0.1.6.0-HC5utweDa8VL0DUiYO0v68
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/rio-prettyprint#readme
synopsis:             Pretty-printing for RIO
description:          Combine RIO'\''s log capabilities with pretty printing
category:             Development
abi:                  f3c23432f2f836ac6b06b09692965d10
exposed:              True
exposed-modules:
    RIO.PrettyPrint RIO.PrettyPrint.DefaultStyles
    RIO.PrettyPrint.PrettyException RIO.PrettyPrint.Simple
    RIO.PrettyPrint.StylesUpdate RIO.PrettyPrint.Types
    Text.PrettyPrint.Leijen.Extended

hidden-modules:       Paths_rio_prettyprint
import-dirs:          /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rio-prettyprint-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rio-prettyprint
hs-libraries:         HSrio-prettyprint-0.1.6.0-HC5utweDa8VL0DUiYO0v68
depends:
    Cabal-3.6.3.0 aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    annotated-wl-pprint-0.7.0-JJ8k3Us8XMDCld6qYY6FFz
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE array-0.5.4.0
    base-4.16.4.0 colour-2.3.6-HdI1cmU1Wok1ucyzh0SdSS mtl-2.2.2
    path-0.9.5-9124ykIABMXHDmnxFXSd3D
    rio-0.1.22.0-CCynOv5jacWCBs6SD5CPpT text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-rio-prettyprint/html/rio-prettyprint.haddock

haddock-html:         /usr/share/doc/haskell-rio-prettyprint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
